@@ -1,22 +1,21 @@
 import 'package:args/args.dart';
 import 'package:args/command_runner.dart';
 
-import '../services/logger_service.dart';
-import '../utils/commands.dart';
+import '../services/flutter_service.dart';
 import '../workflows/ensure_cache.workflow.dart';
+import '../workflows/validate_flutter_version.workflow.dart';
 import 'base_command.dart';
 
 /// Spawn Flutter Commands in other versions
-class SpawnCommand extends BaseCommand {
+class SpawnCommand extends BaseFvmCommand {
   @override
   final name = 'spawn';
   @override
-  final description = 'Spawns a command on a Flutter version';
+  final description = 'Executes Flutter commands using a specific SDK version';
   @override
   final argParser = ArgParser.allowAnything();
 
-  /// Constructor
-  SpawnCommand();
+  SpawnCommand(super.context);
 
   @override
   Future<int> run() async {
@@ -27,17 +26,22 @@ class SpawnCommand extends BaseCommand {
       );
     }
 
+    final validateFlutterVersion = ValidateFlutterVersionWorkflow(context);
+    final ensureCache = EnsureCacheWorkflow(context);
     final version = argResults!.rest[0];
-
     // Removes version from first arg
     final flutterArgs = [...?argResults?.rest]..removeAt(0);
 
-    // Will install version if not already instaled
-    final cacheVersion = await ensureCacheWorkflow(version);
+    final flutterVersion = validateFlutterVersion(version);
+    // Will install version if not already installed
+    final cacheVersion = await ensureCache(flutterVersion);
     // Runs flutter command with pinned version
     logger.info('Spawning version "$version"...');
 
-    final results = await runFlutter(flutterArgs, version: cacheVersion);
+    final results = await get<FlutterService>().runFlutter(
+      flutterArgs,
+      cacheVersion,
+    );
 
     return results.exitCode;
   }
